ProSHADE: Class Members - Functions

| ProSHADE 0.7.5.4 (MAR 2021) Protein Shape Detection

### - r -

- readInMAP() : ProSHADE_internal_data::ProSHADE_data
- readInPDB() : ProSHADE_internal_data::ProSHADE_data
- readInStructure() : ProSHADE_internal_data::ProSHADE_data
- removePhaseInormation() : ProSHADE_internal_data::ProSHADE_data
- removeSmallPeaks() : ProSHADE_internal_spheres::ProSHADE_rotFun_sphere
- reportOverlayResults() : ProSHADE_internal_data::ProSHADE_data
- reportSymmetryResults() : ProSHADE_internal_data::ProSHADE_data
- reSampleMap() : ProSHADE_internal_data::ProSHADE_data
- rotateMap() : ProSHADE_internal_data::ProSHADE_data